==> auth-2.3.0911.6-sources.jar: com/zing/zalo/zalosdk/oauth/ZaloSDKApplication.java <==
package com.zing.zalo.zalosdk.oauth;

import android.app.Application;
import android.content.Context;
import android.content.pm.PackageManager.NameNotFoundException;
import android.os.Build.VERSION;
import android.os.Bundle;
import com.zing.zalo.zalosdk.core.helper.Utils;
import com.zing.zalo.zalosdk.core.log.Log;

public class ZaloSDKApplication extends Application {
    private static boolean a = true;
    protected static long appID = 0;
    protected static String facebookAppID = "";

    private static void a(Application application) {
        ZaloOAuth.Instance = ZaloSDK.Instance;
        Log.initLogger();
        try {
            Bundle bundle = application.getPackageManager().getApplicationInfo(application.getPackageName(), 128).metaData;
            if (appID == 0) {
                if (bundle.containsKey("com.zing.zalo.zalosdk.appID")) {
                    appID = Long.parseLong((String) bundle.get("com.zing.zalo.zalosdk.appID"));
                } else {
                    appID = Long.parseLong((String) bundle.get("appID"));
                }
            }
            if (bundle.containsKey("com.facebook.sdk.ApplicationId")) {
                facebookAppID = bundle.getString("com.facebook.sdk.ApplicationId");
            }
            if (bundle.containsKey("zuqEnabled")) {
                a = bundle.getBoolean("zuqEnabled", true);
            }
        } catch (NameNotFoundException e) {
        } catch (Exception e2) {
            e2.printStackTrace();
        }
        Utils.initZingAnalytics(application, String.valueOf(appID));
        Utils.setSDKVersionZingAnalytics(ZaloSDK.Instance.getVersion());
        ZaloSDK.Instance.initialize(application);
        try {
            if (VERSION.SDK_INT < 16) {
                Class.forName("android.os.AsyncTask");
            }
        } catch (ClassNotFoundException e3) {
            e3.printStackTrace();
        }
        if (a) {
            try {
                Utils.startQOS(Log.getLogLevel(), application, String.valueOf(appID), ZaloSDK.Instance.getDeviceId(), ZaloSDK.Instance.getSDKId(), ZaloSDK.Instance.getOAuthCode(), String.valueOf(ZaloSDK.Instance.getZaloId()));
            } catch (NoClassDefFoundError e4) {
                Log.w("UserQOS not found.");
            }
        }
    }

    public static void wrap(Application application) {
        a(application);
    }

    protected void attachBaseContext(Context context) {
        super.attachBaseContext(context);
    }

    public void onCreate() {
        super.onCreate();
        a(this);
    }
}

==> auth-2.4.0523.2-sources.jar: com/zing/zalo/zalosdk/oauth/ZaloSDKApplication.java <==
package com.zing.zalo.zalosdk.oauth;

import android.app.Application;
import android.content.Context;
import android.content.pm.PackageManager.NameNotFoundException;
import android.os.Build.VERSION;
import android.os.Bundle;
import com.zing.zalo.zalosdk.core.helper.Utils;
import com.zing.zalo.zalosdk.core.log.Log;

public class ZaloSDKApplication extends Application {
    private static boolean a = false;
    protected static long appID = 0;
    protected static String facebookAppID = "";

    protected void attachBaseContext(Context context) {
        super.attachBaseContext(context);
    }

    public void onCreate() {
        super.onCreate();
        a(this);
    }

    public static void wrap(Application app) {
        a(app);
    }

    private static void a(Application app) {
        ZaloOAuth.Instance = ZaloSDK.Instance;
        Log.initLogger();
        try {
            Bundle bundle = app.getPackageManager().getApplicationInfo(app.getPackageName(), 128).metaData;
            if (appID == 0) {
                if (bundle.containsKey("com.zing.zalo.zalosdk.appID")) {
                    appID = Long.parseLong((String) bundle.get("com.zing.zalo.zalosdk.appID"));
                } else {
                    appID = Long.parseLong((String) bundle.get("appID"));
                }
            }
            if (bundle.containsKey("com.facebook.sdk.ApplicationId")) {
                facebookAppID = bundle.getString("com.facebook.sdk.ApplicationId");
            }
            if (bundle.containsKey("zuqEnabled")) {
                a = bundle.getBoolean("zuqEnabled", true);
            }
        } catch (NameNotFoundException e) {
        } catch (Exception e2) {
            e2.printStackTrace();
        }
        Utils.initZingAnalytics(app, String.valueOf(appID));
        ZaloSDK.Instance.initialize(app);
        try {
            if (VERSION.SDK_INT < 16) {
                Class.forName("android.os.AsyncTask");
            }
        } catch (ClassNotFoundException e3) {
            e3.printStackTrace();
        }
        if (a) {
            try {
                Utils.startQOS(Log.getLogLevel(), app, String.valueOf(appID), ZaloSDK.Instance.getDeviceId(), ZaloSDK.Instance.getSDKId(), ZaloSDK.Instance.getOAuthCode(), String.valueOf(ZaloSDK.Instance.getZaloId()));
            } catch (NoClassDefFoundError e4) {
                Log.w("UserQOS not found.");
            }
        }
    }
}
